@@ -5,7 +5,7 @@ use warnings FATAL => 'all';
 use Scalar::Util ();
 use Exporter 5.57 qw(import);
 
-our $VERSION = '1.000007';
+our $VERSION = '1.000009';
 
 our @EXPORT = qw($_call_if_object $_isa $_can $_does $_DOES $_call_if_can);
 
@@ -15,18 +15,31 @@ our $_call_if_object = sub {
   # we gratuitously break modules like Scalar::Defer, which would be
   # un-perlish.
   return unless Scalar::Util::blessed($obj);
-  return $obj->isa(@_) if lc($method) eq 'does' and not $obj->can($method);
   return $obj->$method(@_);
 };
 
-our ($_isa, $_can, $_does, $_DOES) = map {
+our ($_isa, $_can) = map {
   my $method = $_;
   sub { my $obj = shift; $obj->$_call_if_object($method => @_) }
-} qw(isa can does DOES);
+} qw(isa can);
 
 our $_call_if_can = sub {
   my ($obj, $method) = (shift, shift);
-  $obj->$_call_if_object(can => $method) && $obj->$_call_if_object($method => @_);
+  return unless $obj->$_call_if_object(can => $method);
+  return $obj->$method(@_);
+};
+
+our $_does = sub {
+  my $obj = shift;
+  $obj->$_call_if_can(does => @_);
+};
+
+our $_DOES = sub {
+  my $obj = shift;
+  return unless Scalar::Util::blessed($obj);
+  return $obj->DOES(@_)
+    if $obj->can('DOES');
+  return $obj->isa(@_);
 };
 
 1;
@@ -123,6 +136,9 @@ class names that you might not want to treat as one (like say "Matt") - the
 C<is_module_name> function from L<Module::Runtime> is a good way to check for
 something you might be able to call methods on if you want to do that.
 
+We are careful to make sure that scalar/list context is preserved for the
+method that is eventually called.
+
 =head1 EXPORTS
 
 =head2 $_isa
@@ -144,14 +160,17 @@ returns nothing.
   $maybe_an_object->$_does('Foo');
 
 If called on an object, calls C<does> on it and returns the result, otherwise
-returns nothing.
+returns nothing. If the C<does> method does not exist, returns nothing rather
+than failing.
 
 =head2 $_DOES
 
   $maybe_an_object->$_DOES('Foo');
 
 If called on an object, calls C<DOES> on it and returns the result, otherwise
-returns nothing.
+returns nothing. On perl versions prior to 5.10.0, the built in core C<DOES>
+method doesn't exist. If the method doesn't exist, this will fall back to
+calling C<isa> just like the core C<DOES> method.
 
 =head2 $_call_if_object
 
